# Dosage <img src="https://img.shields.io/badge/version-v1.0.2-blue" />

<img src="https://github.com/user-attachments/assets/9695decc-810a-4f28-aa64-452e7cc905a8" width="100%" />

_Dosage_ is a Python library to perform visual saliency detection on images and videos

- [Documentation](https://big-nacho.github.io/dosage-docs/)
- [Showcase](https://big-nacho.github.io/dosage-docs/showcase.html)

## Installation

_Dosage_ is currently supported on macOS and Linux. If you're one Windows,
you may be able to run it via WSL.

### PyPI
```bash
pip install pydosage
```

### Installing from source
```bash
git clone https://github.com/big-nacho/dosage
cd dosage
pip install . -v
```

## Trying it out
To quickly test out your own images and videos, check out the [example folder](examples)

`write_to_disk.py` lets you process a video and save it to disk<br/>
`real_time.py` lets you process a video and get feedback in real time
